/*
FILE: main_rumble.cpp
DESCRIPTION: Test file demonstrating the usage of the PS2Pad library.
             Specifically, the rumble features are shown.
WRITTEN BY: Derek Nedelman (nedelman@netzero.net)
DATE: August 12, 2002
HOME PAGE: http://www.playstation2-linux.com/projects/joypadlib 
*/

#include <stdio.h>
#include "PS2Pad.h"
#include <math.h>

class SmallVibration: public PS2PadVibrationEffect 
{ 
public: 
	void Update(float elapsedTime)	{}
	bool IsDone() const		{return false;}
	void GetIntensities(unsigned char& smallIntensity, unsigned char& bigIntensity)
	{
		smallIntensity = 1;
	}
}; 

class BigVibration: public PS2PadVibrationEffect 
{ 
public: 
	void Update(float elapsedTime)	{}
	bool IsDone() const		{return false;}
	void GetIntensities(unsigned char& smallIntensity, unsigned char& bigIntensity)
	{
		bigIntensity = 255;
	}
}; 

class AllVibration: public PS2PadVibrationEffect 
{ 
public: 
	void Update(float elapsedTime)	{}
	bool IsDone() const		{return false;}
	void GetIntensities(unsigned char& smallIntensity, unsigned char& bigIntensity)
	{
		smallIntensity = 1;
		bigIntensity = 255;
	}
}; 

class WaveVibration: public PS2PadVibrationEffect 
{ 
	float totalTime;

public: 
	WaveVibration()			{totalTime = 0.0f;}
	void Update(float elapsedTime)	{totalTime += elapsedTime;}
	bool IsDone() const		{return false;}
	void GetIntensities(unsigned char& smallIntensity, unsigned char& bigIntensity)
	{
		float sinTime = fabsf(sinf(totalTime) * 10.0f);	
		bigIntensity = (unsigned char)(sinTime * 255);
	}
}; 

int main(int argc, char** argv)
{
	PS2Pad* joypad;
	SmallVibration smallVibration;
	BigVibration bigVibration;
	AllVibration allVibration;
	WaveVibration waveVibration;
	
	PS2PadManager::Initialize();
	joypad = PS2PadManager::GetPad(0);

	puts("Press the SQUARE button to turn on the small vibration effect.");
	puts("Press the TRIANGLE button to turn on the big vibration effect.");
	puts("Press the CIRCLE button to turn on the full vibration effect.");
	puts("Press the CROSS button to turn on the wave vibration effect.");
	puts("Press the SELECT button to end any effect.");
	puts("Press the START button to exit.");
	
	for (;;) 
	{
		PS2PadManager::Update();
		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_START))
		{
			puts("Pressed start");
			break;
		}		
		
		if (joypad->WasButtonPressed(PS2Pad::BUTTON_SQUARE))
		{
			puts("Pressed square. Turning on the small vibration effect");
			joypad->SetVibrationEffect(&smallVibration);
		} 
		if (joypad->WasButtonPressed(PS2Pad::BUTTON_TRIANGLE))
		{
			puts("Pressed triangle. Turning on the big vibration effect");
			joypad->SetVibrationEffect(&bigVibration);
		}		
		if (joypad->WasButtonPressed(PS2Pad::BUTTON_CIRCLE))
		{			
			puts("Pressed circle. Turning on the full vibration effect");
			joypad->SetVibrationEffect(&allVibration);
		}		
		if (joypad->WasButtonPressed(PS2Pad::BUTTON_CROSS))
		{
			puts("Pressed cross. Turning on the wave vibration effect");
			joypad->SetVibrationEffect(&waveVibration);
		}
		if (joypad->WasButtonPressed(PS2Pad::BUTTON_SELECT))
		{
			puts("Pressed SELECT. Stopping current vibration effect.");
			joypad->SetVibrationEffect(0);
		}
	}
	
	PS2PadManager::Shutdown();
	return 0;
}
